.. _capi-atom:

Function manipulating ``CHFL_ATOM``
-----------------------------------

.. doxygentypedef:: CHFL_ATOM

.. doxygenfunction:: chfl_atom

.. doxygenfunction:: chfl_atom_from_frame

.. doxygenfunction:: chfl_atom_from_topology

.. doxygenfunction:: chfl_atom_copy

.. doxygenfunction:: chfl_atom_mass

.. doxygenfunction:: chfl_atom_set_mass

.. doxygenfunction:: chfl_atom_charge

.. doxygenfunction:: chfl_atom_set_charge

.. doxygenfunction:: chfl_atom_name

.. doxygenfunction:: chfl_atom_set_name

.. doxygenfunction:: chfl_atom_type

.. doxygenfunction:: chfl_atom_set_type

.. doxygenfunction:: chfl_atom_full_name

.. doxygenfunction:: chfl_atom_vdw_radius

.. doxygenfunction:: chfl_atom_covalent_radius

.. doxygenfunction:: chfl_atom_atomic_number

.. doxygenfunction:: chfl_atom_set_property

.. doxygenfunction:: chfl_atom_get_property

.. doxygenfunction:: chfl_atom_free
